@@ -5,10 +5,13 @@ from .capture_api import CaptureApi
 from .conversion_details_api import ConversionDetailsApi
 from .credit_api import CreditApi
 from .decision_manager_api import DecisionManagerApi
+from .download_dtd_api import DownloadDTDApi
+from .download_xsd_api import DownloadXSDApi
 from .instrument_identifier_api import InstrumentIdentifierApi
 from .key_generation_api import KeyGenerationApi
 from .net_fundings_api import NetFundingsApi
 from .notification_of_changes_api import NotificationOfChangesApi
+from .payment_batch_summaries_api import PaymentBatchSummariesApi
 from .payment_instrument_api import PaymentInstrumentApi
 from .payments_api import PaymentsApi
 from .payouts_api import PayoutsApi
